@@ -1,6 +1,6 @@
 # GNU Enterprise Navigator - Client
 #
-# Copyright 2001-2004 Free Software Foundation
+# Copyright 2001-2005 Free Software Foundation
 #
 # This file is part of GNU Enterprise
 #
@@ -19,9 +19,8 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: GNClient.py 6568 2004-10-26 14:29:09Z johannes $
+# $Id: GNClient.py 7578 2005-06-06 07:18:50Z kilo $
 
-import pstats
 import os
 import sys
 import urllib
@@ -30,7 +29,6 @@ from gnue.navigator.GNParser import loadProcesses
 from gnue.navigator import Actions
 from gnue.common.apps import errors
 from gnue.common.utils.FileUtils import openResource, dyn_import
-from gnue.common.datasources import GDataObjects, GConnections
 from gnue.common.apps.GClientApp import *
 from gnue import paths
 from gnue.navigator import VERSION
