@@ -1,7 +1,7 @@
 #
-# Copyright 2001-2004 Free Software Foundation
+# Copyright 2001-2005 Free Software Foundation
 #
-# This file is part of GNU Enterprise.
+# This file is part of GNU Enterprise
 #
 # GNU Enterprise is free software; you can redistribute it
 # and/or modify it under the terms of the GNU General Public
@@ -18,13 +18,13 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# FILE:
-# GNConfig.py
-#
-# DESCRIPTION:
-#
-# NOTES:
-#
+# $Id: GNConfig.py 7040 2005-02-18 11:22:44Z kilo $
+
+"""
+Valid configuration options for navigator
+(appears under [navigator] section in gnue.conf)
+"""
+
 from gnue.common.formatting import GTypecast
 
 ConfigOptions = (
@@ -68,19 +68,21 @@ ConfigOptions = (
     'Comment'    : "Do not display the splashscreen.",
     'Description': "Do not display the splashscreen.",
     'Typecast'   : GTypecast.boolean,
-    'Default'    : 1 },
+    'Default'    : True },
   
   { 'Name'       : 'embedForms',
     'Type'       : 'Setting',
     'Comment'    : "Do not open separate window to display a GNUe Form.",
     'Description': "Do not open separate window to display a GNUe Form.",
     'Typecast'   : GTypecast.boolean,
-    'Default'    : 1 },
+    'Default'    : True },
 
   { 'Name'       : 'hourglassDelay',
     'Type'       : 'Setting',
-    'Comment'    : "The number of seconds to display the hourglass when launching a program",
-    'Description': "The number of seconds to display the hourglass when launching a program",
+    'Comment'    : 'The number of seconds to display the hourglass '
+                 + 'when launching a program.',
+    'Description': 'The number of seconds to display the hourglass '
+                 + 'when launching a program.',
     'Typecast'   : GTypecast.whole,
     'Default'    : 5 },
 )
