@@ -1,6 +1,6 @@
 # GNU Enterprise Navigator - GTK Frontent
 #
-# Copyright 2001-2004 Free Software Foundation
+# Copyright 2001-2005 Free Software Foundation
 #
 # This file is part of GNU Enterprise
 #
@@ -19,7 +19,7 @@
 # write to the Free Software Foundation, Inc., 59 Temple Place
 # - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: UIgtk2.py 6568 2004-10-26 14:29:09Z johannes $
+# $Id: UIgtk2.py 7664 2005-06-28 02:40:20Z dimas $
 
 import pygtk
 pygtk.require('2.0')
@@ -277,7 +277,8 @@ class Instance:
       node = store.append (None, [gnObject.title, gnObject])
 
     elif gnObject._type in ['GNStep', 'GNProcess']:
-      node = store.append (gnObject._parent.__node, [gnObject.title, gnObject])
+      node = store.append (gnObject.getParent ().__node,
+                           [gnObject.title, gnObject])
 
     else:
       return
@@ -635,7 +636,7 @@ class Instance:
     self._formInstances [id (self)] = instance
          
     instance.addFormFromFile (formfile)
-    instance.addDialogs ()
+    #instance.addDialogs ()
     instance.activate ()
 
 
