@@ -1,5 +1,5 @@
 #
-# Copyright 2002-2004 Free Software Foundation
+# Copyright 2002-2005 Free Software Foundation
 #
 # This file is part of GNU Enterprise.
 #
@@ -30,6 +30,7 @@
 # reuse GNUe Form's UI* classes if at all possible.
 
 import string, sys
+from gnue.common.datasources.GLoginHandler import BasicLoginHandler
 
 class Instance:
   def __init__(self, processes):
@@ -38,7 +39,7 @@ class Instance:
   def run(self, connections):
     print "Login Handler set"
     
-    connections.setLoginHandler(LoginHandler())
+    connections.setLoginHandler (BasicLoginHandler ())
     self.buildMenu(self.processes)
     
     self.connections = connections
@@ -83,15 +84,15 @@ class Instance:
 
       print
 
-      if process._parent:
+      if process.getParent ():
 
-        top = process._parent
-        while top._parent:
-          top = top._parent
+        top = process.getParent ()
+        while top.getParent ():
+          top = top.getParent ()
 
-        if top != process._parent:
-          print '  P: Back to %s'% process._parent.title
-          self.selections['P'] = process._parent
+        if top != process.getParent ():
+          print '  P: Back to %s'% process.getParent ().title
+          self.selections['P'] = process.getParent ()
 
         print "  T: Back to Top"
         self.selections['T'] = top
@@ -139,43 +140,3 @@ def getInput(message, default, responseSet=None):
       return string.upper(val)
     elif not responseSet:
       return val
-
-
-from gnue.common.datasources import GLoginHandler
-import getpass
-class LoginHandler(GLoginHandler.LoginHandler):
-
-  defaults = {'_username': None, '_password': None}
-
-  def getLogin(self, loginData, error):
-    try:
-      print ( "*"*60 )
-      if len(loginData[1]):
-        print ( 'Attempting to log into "%s" (%s):' % (loginData[1], loginData[0]) )
-      else:
-        print ( 'Attempting to log into %s:' % (loginData[0]) )
-      print ("")
-      val = {}
-      for prompt in loginData[2]:
-         if self.defaults.has_key(prompt[0])  and self.defaults[prompt[0]]:
-           print_nl ( "  %s: " % prompt[1] )
-           if prompt[2]:
-             print ( "***" )
-           else:
-             print ( self.defaults[prompt[0]] )
-           val[prompt[0]] = self.defaults[prompt[0]]
-         else:
-           if prompt[2]:
-             val[prompt[0]] = getpass.getpass("  %s: " % prompt[1])
-           else:
-             val[prompt[0]] = raw_input("  %s: " % prompt[1])
-      print ("")
-      print ("*"*60)
-      return val
-    except KeyboardInterrupt:
-      raise GLoginHandler.UserCanceledLogin
-
-
-  def destroyLoginDialog(self):
-    pass
-
