@@ -1,5 +1,5 @@
 #
-# Copyright 2002-2004 Free Software Foundation
+# Copyright 2002-2005 Free Software Foundation
 #
 # This file is part of GNU Enterprise.
 #
@@ -84,10 +84,10 @@ class Instance(wxApp):
     # if this is not the top branch
     if process!=self.processes:
 
-      url = '%s' % id(process._parent)
-      html += self.getHtmlBack(url, process._parent.title, \
-                               process._parent._type)
-      self.selections['%s' % id(process._parent)] = process._parent
+      url = '%s' % id(process.getParent ())
+      html += self.getHtmlBack(url, process.getParent ().title, \
+                               process.getParent ()._type)
+      self.selections['%s' % id(process.getParent ())] = process.getParent ()
 
     html += self.getHtmlFooter()
 
