@@ -1,5 +1,5 @@
 #
-# Copyright 2002-2004 Free Software Foundation
+# Copyright 2002-2005 Free Software Foundation
 #
 # This file is part of GNU Enterprise.
 #
@@ -29,8 +29,25 @@
 # reuse GNUe Form's UI* classes if at all possible.
 
 
-import os, sys
-from gnue.common.datasources import GDataObjects, GConnections
+import os
+import sys
+import struct
+import array
+import tempfile
+
+import win32api
+import win32gui
+import win32ui
+import win32con
+import commctrl
+from pywin.mfc import window, activex
+from win32com.client import gencache
+
+WebBrowserModule = gencache.EnsureModule("{EAB22AC0-30C1-11CF-A7EB-0000C05BAE0B}", 0, 1, 1)
+if WebBrowserModule is None:
+  raise ImportError, "IE4 does not appear to be installed."
+
+from gnue.common.datasources import Exceptions, GConnections
 from gnue.common.utils.FileUtils import dyn_import, openResource
 from gnue.common.apps import GConfig
 from gnue.navigator import VERSION
@@ -47,14 +64,6 @@ except ImportError:
   FORMS_SUPPORT=1
   print 'GNUe Forms is not installed on your system'
 
-import struct, array, tempfile
-import win32api, win32gui, win32ui, win32con, commctrl
-from pywin.mfc import window, activex
-from win32com.client import gencache
-
-WebBrowserModule = gencache.EnsureModule("{EAB22AC0-30C1-11CF-A7EB-0000C05BAE0B}", 0, 1, 1)
-if WebBrowserModule is None:
-  raise ImportError, "IE4 does not appear to be installed."
 
 ID_EXIT = getNextId()
 ID_FAV_ORG = getNextId()
@@ -191,7 +200,7 @@ class Instance:
     nmask, nhItem, nstate, nstateMask, npszText, ncchTextMax, niImage, niSelectedImage, ncChildren, nlParam,\
     x,y \
       = struct.unpack(format, buf)
-    code += 0x4f0000 # hrm - wtf - commctrl uses this, and it works with mfc.  *sigh*
+    code += commctrl.PY_0U
 
     if code == commctrl.TVN_SELCHANGED:
       object = self._mapping[nhItem]
@@ -201,8 +210,11 @@ class Instance:
           content = item.getChildrenAsContent()
           self.tempfileHandle.seek(0)
           self.tempfileHandle.truncate()
-          self.tempfileHandle.write("<html\n>")
-          self.tempfileHandle.write(content)
+#          self.tempfileHandle.write("<html\n>")
+          self.tempfileHandle.write(u"<html><head><meta http-equiv='Content-Type' \
+		    content='text/html; charset=utf8'></head><body>")
+          self.tempfileHandle.write(content.encode('utf8'))
+          self.tempfileHandle.write(u"</body></html>")
           self.tempfileHandle.flush()
           self.browser.ocx.Refresh()
           break
@@ -247,7 +259,7 @@ class Instance:
     if object._type == 'GNProcesses':
       node = self.__addItem(None, object.title,1)
     elif object._type in ('GNStep','GNProcess'):
-      node = self.__addItem(object._parent.__node, object.title,2)
+      node = self.__addItem(object.getParent ().__node, object.title,2)
     else:
       return
 
@@ -292,7 +304,6 @@ class Instance:
     # peek at the abort variable
 
     # TODO: Pass parameters
-
     if os.path.basename(step.location) == step.location:
       try:
         formdir = gConfigNav('FormDir')
@@ -301,7 +312,6 @@ class Instance:
       formfile = formdir+"/"+step.location
     else:
       formfile = step.location
-
     self._runForm(formfile, step._params)
 
 
@@ -326,28 +336,18 @@ class Instance:
       #
       # Start the instance
       #
-      instance.addDialogs()
+      #instance.addDialogs()
           
       #instance.buildForm(form)
       instance.activate()
 
-    except GConnections.Error, mesg:
-      self.handleError(mesg)
-
     except IOError, mesg:
       self.handleError(_("Unable to open file\n\n     %s")%mesg)
 
-    except GDataObjects.ConnectError, mesg:
-      self.handleError(\
-         _("Unable to login to datasource.\n\n       %s") %mesg)
-
-    except GDataObjects.ConnectionError, mesg:
+    except Exceptions.ConnectionError, mesg:
       self.handleError(\
          _("Error while communicating with datasource.\n\n       %s") %mesg)
 
-    except GDataObjects.Error, mesg:
-      self.handleError(mesg)
-
 
   def handleStartupError(self, errortext):
     print
