@@ -1,5 +1,5 @@
 #
-# Copyright 2002-2004 Free Software Foundation
+# Copyright 2002-2005 Free Software Foundation
 #
 # This file is part of GNU Enterprise.
 #
@@ -33,7 +33,7 @@ from wxPython.wx import *
 from wxPython.html import *
 from time import sleep
 import os, sys, string
-from gnue.common.datasources import GDataObjects, GConnections
+from gnue.common.datasources import Exceptions, GConnections
 from gnue.common.utils.FileUtils import dyn_import, openResource
 from gnue.common.apps import GConfig
 from gnue.navigator import VERSION
@@ -130,7 +130,7 @@ class Instance:
     if object._type == 'GNProcesses':
       node = self.tree.AddRoot(object.title.encode(gConfig('textEncoding'),'replace'))
     elif object._type in ('GNStep','GNProcess'):
-      node = self.tree.AppendItem(object._parent.__node, object.title.encode(gConfig('textEncoding'),'replace'))
+      node = self.tree.AppendItem(object.getParent ().__node, object.title.encode(gConfig('textEncoding'),'replace'))
     else:
       return
 
@@ -234,7 +234,7 @@ class Instance:
         formdir = gConfigNav('FormDir')
       except KeyError:
         formdir = ""
-      formfile = formdir+"/"+step.location
+      formfile = os.path.join (formdir, step.location)
     else:
       formfile = step.location
 
@@ -282,28 +282,18 @@ class Instance:
       #
       # Start the instance
       #
-      instance.addDialogs()
+      #instance.addDialogs()
 
       #instance.buildForm(form)
       instance.activate()
 
-    except GConnections.Error, mesg:
-      self.handleError(mesg)
-
     except IOError, mesg:
       self.handleError(_("Unable to open file\n\n     %s")%mesg)
 
-    except GDataObjects.ConnectError, mesg:
-      self.handleError(\
-         _("Unable to login to datasource.\n\n       %s") %mesg)
-
-    except GDataObjects.ConnectionError, mesg:
+    except Exceptions.ConnectionError, mesg:
       self.handleError(\
          _("Error while communicating with datasource.\n\n       %s") %mesg)
 
-    except GDataObjects.Error, mesg:
-      self.handleError(mesg)
-
   def setTitle(self, title):
     self.frame.SetTitle ("GNUe Navigator: %s (form)" % title )
 
